

#ifndef STDB_INTERF_INCLUDED
#define STDB_INTERF_INCLUDED


/* --------------------------------------------------------------------- */

int stdb_query_setup (
    const int   dbproc,         /* i: index into context array          */
    const char *module_name,    /* i: name of module performing query   */
    const int   query_num       /* i: number of query within module     */
    );

/* --------------------------------------------------------------------- */

int stdb_set_null (
    const int   dbproc,         /* i: index into context array             */
    const int   bindtype,       /* i: type of variable binding to which    */
                                /*    substitute value applies             */
    const int   bindlen,        /* i: length of substitute value           */
    const void *bindval         /* i: pointer to substitute value          */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_float (
    const int    dbproc,        /* i:   index into context array              */
    const char  *column_name,   /* i:   name of column to bind                */
    volatile float *varaddr     /* i/o: address of bind variable to which the */
                                /*      data will be copied                   */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_double (
    const int     dbproc,       /* i:   index into context array            */
    const char   *column_name,  /* i:   name of column to bind              */
    volatile double *varaddr    /* i/o: address of bind variable to which   */
                                /*      the data will be copied             */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_string (
    const int   dbproc,        /* i:   index into context array               */
    const char *column_name,   /* i:   name of column to bind                 */
    volatile char *varaddr,    /* i/o: address of bind variable to which the  */
                               /*      data will be copied                    */
    const int   varlen         /* i:   The length of the program variable     */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_binary (
    const    int  dbproc,       /* i:   index into context array	    */
    const    char *column_name, /* i:   name of column to bind		    */
    volatile unsigned char *varaddr, /* i/o: address of bind variable to   */
			        /*      which the data will be copied	   */
    const    int  len           /* i:   length of binary data		    */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_single_char (
    const int   dbproc,       /* i:   index into context array               */
    const char *column_name,  /* i:   name of column to bind                 */
    volatile char   *varaddr  /* i/o: address of bind variable to which the  */
                              /*      data will be copied                    */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_int (
    const int   dbproc,       /* i:   index into context array               */
    const char *column_name,  /* i:   name of column to bind                 */
    volatile int   *varaddr   /* i/o: address of bind variable to which the  */
                              /*      data will be copied                    */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_short (
    const int    dbproc,      /* i:   index into context array               */
    const char  *column_name, /* i:   name of column to bind                 */
    volatile short *varaddr   /* i/o: address of bind variable to which the  */
                              /*      data will be copied                    */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_text (
    const int   dbproc,       /* i:   index into context array               */
    const char *column_name,  /* i:   name of column to bind                 */
    volatile void *varaddr,   /* i/o: address of bind variable to which the  */
                              /*      data will be copied                    */
    int  *varlen              /* o:   address of variable to hold length of  */
                              /*      returned text                          */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_image (
    const int   dbproc,      /* i:   index into context array               */
    const char *column_name, /* i:   name of column to bind                 */
    volatile void *varaddr,  /* i/o: address of bind variable to which the  */
                             /*      data will be copied                    */
    int  *varlen             /* o:   address of variable to hold length of  */
                             /*      returned text                          */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_datetime (
    const int   dbproc,         /* i:   index into context array         */
    const char *column_name,    /* i:   name of column to bind           */
    volatile STDB_DATEREC_TYPE *varaddr /* i/o: address of bind variable */
                                /*      to which the data will be copied */
    );

/* --------------------------------------------------------------------- */

int stdb_stored_command (
    const int   dbproc,         /* i: index into context array           */
    const char *procedure_name  /* i: stored procedure name              */
    );

/* --------------------------------------------------------------------- */

int stdb_single_char_param (
    const int   dbproc,         /* i: index into context array    */
    const char *param_name,     /* i: parameter name              */
    const char  param_value     /* i: parameter value             */
    );

/* --------------------------------------------------------------------- */

int stdb_int_param (
    const int   dbproc,         /* i: index into context array    */
    const char *param_name,     /* i: parameter name              */
    const int   param_value     /* i: parameter value             */
    );

/* --------------------------------------------------------------------- */

int stdb_short_param (
    const int    dbproc,        /* i: index into context array  */
    const char  *param_name,    /* i: parameter name            */
    const short  param_value    /* i: parameter value           */
    );

/* --------------------------------------------------------------------- */

int stdb_double_param (
    const int    dbproc,        /* i: index into context array   */
    const char  *param_name,    /* i: parameter name             */
    const double param_value    /* i: parameter value            */
    );

/* --------------------------------------------------------------------- */

int stdb_real_param (
    const int    dbproc,        /* i: index into context array  */
    const char  *param_name,    /* i: parameter name            */
    const float  param_value    /* i: parameter value           */
    );

/* --------------------------------------------------------------------- */

int stdb_string_param (
    const int   dbproc,         /* i: index into context array        */
    const char  *param_name,    /* i: parameter name                  */
    const char  *param_value    /* i: parameter value                 */
    );

/* --------------------------------------------------------------------- */

int stdb_binary_param (
    const int   dbproc,               /* i: index into context array    */
    const char *param_name,           /* i: parameter name              */
    const unsigned char *param_value, /* i: parameter value             */
    const int  param_len              /* i: length of parameter value   */
    );

/* --------------------------------------------------------------------- */

int stdb_text_param (
    const int   dbproc,         /* i: index into context array        */
    const char  *param_name,    /* i: parameter name                  */
    const void  *param_value    /* i: parameter value                 */
    );

/* --------------------------------------------------------------------- */

int stdb_int_ret_param (
    const int   dbproc,      /* i:   index into context array               */
    const char *param_name,  /* i:   parameter name                         */
    int  *param_addr         /* i/o: address of return int parameter to     */
                             /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_short_ret_param(
    const int    dbproc,       /* i:   index into context array               */
    const char  *param_name,   /* i:   parameter name                         */
    short *param_addr          /* i/o: address of return short parameter to   */
                               /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_double_ret_param (
    const int    dbproc,      /* i:   index into context array               */
    const char   *param_name, /* i:   parameter name                         */
    double *param_addr        /* i/o: address of return double parameter to  */
                              /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_float_ret_param (
    const int   dbproc,      /* i:   index into context array               */
    const char  *param_name, /* i:   parameter name                         */
    float *param_addr        /* i/o: address of return float parameter to   */
                             /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_string_ret_param (
    const int   dbproc,      /* i:   index into context array               */
    const char *param_name,  /* i:   parameter name                         */
    char *param_addr,        /* i/o: address of return string parameter to  */
                             /*      which the data will be copied          */
    const int   param_len    /* i:   length of string parameter             */
    );

/* --------------------------------------------------------------------- */

int stdb_single_char_ret_param (
    const int   dbproc,      /* i:   index into context array               */
    const char *param_name,  /* i:   parameter name                         */
    char *param_addr         /* i/o: address of return string parameter to  */
                             /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_query (
    const int   dbproc,         /* i: index into context array       */
    const char *cmd_string      /* i: command string to be appended  */
    );

/* --------------------------------------------------------------------- */

int stdb_get_exec (
    const int   dbproc          /* i: index into context array       */
    );

/* --------------------------------------------------------------------- */

int stdb_null_param (
    const int   dbproc,         /* i: index into context array  */
    const char *param_name      /* i: parameter name            */
    );

/* --------------------------------------------------------------------- */

int stdb_close_query (
    const int   dbproc          /* i: index into context array     */
    );

/* --------------------------------------------------------------------- */

int stdb_set_ql (
    const int   dbproc,     /* i: index into context array                 */
    const int   query_type  /* i: query language type:STDB_IQL or STDB_SQL */
                            /*    We know this is a Lint error since not   */
                            /*    used, but we are keeping this because we */
                            /*    hope that IQL will someday be the        */
                            /*    industry standard (just kidding) -       */
                            /*    database humor - ar ar ar                */
    );

/* --------------------------------------------------------------------- */

double stdb_backend_cpu_time (
    const int   dbproc          /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_record_count (
    const int   dbproc          /* i: index into context array       */
    );

/* --------------------------------------------------------------------- */

int stdb_current_record_count (
    const int   dbproc          /* i: index into context array        */
    );

/* --------------------------------------------------------------------- */

int stdb_is_null (
    const int   dbproc,         /* i: index into context array      */
    const void *varaddr         /* i: bound variable                */
    );

/* --------------------------------------------------------------------- */

int stdb_get_status (
    const int   dbproc          /* i: index into context array      */
    );

/* --------------------------------------------------------------------- */

int stdb_get_alternate_status (
    const int   dbproc          /* i: index into context array */
    );

/* --------------------------------------------------------------------- */

int stdb_set_alternate_status (
    const int dbproc,           /* i: index into context array      */
    const int alternate_status  /* i: alternate status to be set    */
    );

/* --------------------------------------------------------------------- */

int stdb_get_current_process ();

/* --------------------------------------------------------------------- */

int stdb_in_transaction (
    const int   dbproc          /* i: index into context array    */
    );

/* --------------------------------------------------------------------- */

int stdb_set_textsize (
    const int   dbproc,         /* i: index into context array       */
    const int   text_size       /* i: test/image size to be set      */
    );

/* --------------------------------------------------------------------- */

int stdb_cancel (
    const int   dbproc          /* i: index into context array    */
    );

/* --------------------------------------------------------------------- */

void stdb_fstr_to_cstr (
#ifdef STDB_VMS
    const struct dsc$descriptor_s *str,  /* i: FORTRAN string descriptor(VMS) */
#else
    const void  *fstr,                   /* i: FORTRAN string (Unix)          */
#endif
    const int    len,                    /* i: string length                  */
    char  *cstr                          /* o: C string                       */
    ); 

/* --------------------------------------------------------------------- */

int stdb_query_setup_fc (
    const int  *dbproc,         /* i: index into context array           */
    const void *module_name,    /* i: name of module performing query    */
    const int  *module_len,     /* i: length of mudule name              */
    const int  *query_num       /* i: number of query within module      */
    );

/* --------------------------------------------------------------------- */

int stdb_set_null_f (
    const int  *dbproc,           /* i: index into context array           */
    const int  *bindtype,         /* i: type of variable binding to which  */
                                  /*    substitute value applies           */
    const int  *bindlen,          /* i: length of substitute value         */
#ifdef STDB_VMS
    const struct dsc$descriptor_s *bindval
#else
    const void *bindval           /* i: pointer to substitute value        */
#endif
    );

/* --------------------------------------------------------------------- */

int stdb_bind_float_fc (
    const int   *dbproc,        /* i:   index into context array              */
    const void  *column_name,   /* i:   name of column to bind                */
    const int   *name_len,      /* i:   length of column name                 */
    volatile float *varaddr     /* i/o: address of bind variable to which the */
                                /*      data will be copied                   */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_double_fc (
    const int    *dbproc,       /* i:   index into context array              */
    const void   *column_name,  /* i:   name of column to bind                */
    const int    *name_len,     /* i:   length of column name                 */
    volatile double   *varaddr  /* i/o: address of bind variable to which the */
                                /*      data will be copied                   */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_string_fc (
    const int   *dbproc,        /* i:   index into context array              */
    const void  *column_name,   /* i:   name of column to bind                */
    const int   *name_len,      /* i:   length of column name                 */
#ifdef STDB_VMS
    volatile struct dsc$descriptor_s *varaddr,
#else
    volatile char  *varaddr,    /* i/o: address of bind variable to which the */
                                /*      data will be copied                   */
#endif
    const int   *varlen         /* i:   length of bind variable name          */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_int_fc (
    const int   *dbproc,        /* i:   index into context array              */
    const void  *column_name,   /* i:   name of column to bind                */
    const int   *name_len,      /* i:   length of column name                 */
    volatile int *varaddr       /* i/o: address of bind variable to which the */
                                /*      data will be copied                   */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_short_fc (
    const int   *dbproc,       /* i:   index into context array               */
    const void  *column_name,  /* i:   name of column to bind                 */
    const int   *name_len,     /* i:   length of column name                  */
    volatile short *varaddr    /* i/o: address of bind variable to which the  */
                               /*      data will be copied                    */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_text_fc (
    const int   *dbproc,       /* i:   index into context array               */
    const void  *column_name,  /* i:   name of column to bind                 */
    const int   *name_len,     /* i:   length of column name                  */
    volatile void  *varaddr,   /* i/o: address of bind variable to which the  */
                               /*      data will be copied                    */
    int   *varlen              /* o:   address of variable to hold length of  */
                               /*      returned text                          */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_image_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *column_name, /* i:   name of column to bind                 */
    const int   *name_len,    /* i:   length of column name                  */
    volatile void  *varaddr,  /* i/o: address of bind variable to which the  */
                              /*      data will be copied                    */
    int   *varlen             /* o:   address of variable to hold length of  */
                              /*      returned image                         */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_binary_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *column_name, /* i:   name of column to bind                 */
    const int   *name_len,    /* i:   length of column name                  */
    volatile void  *varaddr,  /* i/o: address of bind variable to which the  */
                              /*      data will be copied                    */
    const int   *varlen       /* i:   length of binary variable		     */
    );

/* --------------------------------------------------------------------- */

int stdb_bind_datetime_fc (
    const int   *dbproc,        /* i:   index into context array         */
    const void  *column_name,   /* i:   name of column to bind           */
    const int   *name_len,      /* i:   length of column name            */
    volatile STDB_DATEREC_TYPE *varaddr /* i/o: address of bind variable */
                                /*      to which the data will be copied */
    );

/* --------------------------------------------------------------------- */

int stdb_stored_command_fc (
    const int  *dbproc,         /* i: index into context array          */
    const void *procedure_name, /* i: stored procedure name             */
    const int  *name_len        /* i: length of stored procedure name   */
    );

/* --------------------------------------------------------------------- */

int stdb_single_char_param_fc (
    const int  *dbproc,         /* i: index into context array   */
    const void *param_name,     /* i: parameter name             */
    const int  *name_len,       /* i: length of parameter name   */
    const void *param_value     /* i: parameter value            */
    );  

/* --------------------------------------------------------------------- */

int stdb_int_param_fc (
    const int  *dbproc,         /* i: index into context array   */
    const void *param_name,     /* i: parameter name             */
    const int  *name_len,       /* i: length of parameter name   */
    const int  *param_value     /* i: parameter value            */
    );  

/* --------------------------------------------------------------------- */

int stdb_short_param_fc (
    const int   *dbproc,        /* i: index into context array    */
    const void  *param_name,    /* i: parameter name              */
    const int   *name_len,      /* i: length of parameter name    */
    const short *param_value    /* i: parameter value             */
    );  

/* --------------------------------------------------------------------- */

int stdb_double_param_fc (
    const int    *dbproc,       /* i: index into context array   */
    const void   *param_name,   /* i: parameter name             */
    const int    *name_len,     /* i: length of parameter name   */
    const double *param_value   /* i: parameter value            */
    );

/* --------------------------------------------------------------------- */

int stdb_real_param_fc (
    const int   *dbproc,        /* i: index into context array  */
    const void  *param_name,    /* i: parameter name            */
    const int   *name_len,      /* i: length of parameter name  */
    const float *param_value    /* i: parameter value           */
    );  

/* --------------------------------------------------------------------- */

int stdb_string_param_fc (
    const int  *dbproc,         /* i: index into context array    */
    const void *param_name,     /* i: parameter name              */
    const int  *name_len,       /* i: length of parameter name    */
    const void *param_value,    /* i: parameter value             */
    const int  *val_len         /* i: length of parameter value   */
    );  

/* --------------------------------------------------------------------- */

int stdb_binary_param_fc (
    const int  *dbproc,         /* i: index into context array    */
    const void *param_name,     /* i: parameter name              */
    const int  *name_len,       /* i: length of parameter name    */
    const void *param_value,    /* i: parameter value             */
    const int  *val_len         /* i: length of parameter value   */
    );  

/* --------------------------------------------------------------------- */

int stdb_text_param_fc (
    const int  *dbproc,         /* i: index into context array    */
    const void *param_name,     /* i: parameter name              */
    const int  *name_len,       /* i: length of parameter name    */
    const void *param_value,    /* i: parameter value             */
    const int  *val_len         /* i: length of parameter value   */
    );  

/* --------------------------------------------------------------------- */

int stdb_float_ret_param_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *param_name,  /* i:   parameter name                         */
    const int   *name_len,    /* i:   length of parameter name               */
    float *param_addr         /* i/o: address of return float parameter to   */
                              /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_double_ret_param_fc (
    const int    *dbproc,      /* i:   index into context array               */
    const void   *param_name,  /* i:   parameter name                         */
    const int    *name_len,    /* i:   length of column name                  */
    double *param_addr         /* i/o: address of return double parameter to  */
                               /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_single_char_ret_param_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *param_name,  /* i:   name of column to bind                 */
    const int   *name_len,    /* i:   length of column name                  */
#ifdef STDB_VMS
    struct dsc$descriptor_s *param_addr
#else
    char  *param_addr         /* i/o: address of return parameter to which   */
                              /*      the data will be copied                */
#endif
    );

/* --------------------------------------------------------------------- */

int stdb_string_ret_param_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *param_name,  /* i:   name of column to bind                 */
    const int   *name_len,    /* i:   length of column name                  */
#ifdef STDB_VMS
    struct dsc$descriptor_s *param_addr,
#else
    char  *param_addr,        /* i/o: address of return parameter to which   */
                              /*      the data will be copied                */
#endif
    const int   *varlen       /* i:   length of variable name                */
    );

/* --------------------------------------------------------------------- */

int stdb_int_ret_param_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *param_name,  /* i:   parameter name                         */
    const int   *name_len,    /* i:   length of column name                  */
    int   *param_addr         /* i/o: address of return int parameter to     */
                              /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_short_ret_param_fc (
    const int   *dbproc,      /* i:   index into context array               */
    const void  *param_name,  /* i:   parameter name                         */
    const int   *name_len,    /* i:   length of column name                  */
    short *param_addr         /* i/o: address of return short parameter to   */
                              /*      which the data will be copied          */
    );

/* --------------------------------------------------------------------- */

int stdb_query_fc (
    const int  *dbproc,         /* i: index into context array       */
    const void *cmd_string,     /* i: command string to be appended  */
    const int  *cmd_len         /* i: length of command string       */
    );

/* --------------------------------------------------------------------- */

int stdb_get_exec_fc (
    const int  *dbproc          /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_null_param_fc (
    const int   *dbproc,        /* i: index into context array   */
    const void  *param_name,    /* i: parameter name             */
    const int   *name_len       /* i: length of parameter name   */
    );

/* --------------------------------------------------------------------- */

int stdb_close_query_fc (
    const int  *dbproc          /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_set_ql_fc (
    const int *dbproc,       /* i: index into context array                 */
    const int *query_type    /* i: query language type:STDB_IQL or STDB_SQL */
    );

/* --------------------------------------------------------------------- */

double stdb_backend_cpu_time_f (
    const int *dbproc           /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_record_count_fc (
    const int *dbproc           /* i: index into context array  */
    ); 

/* --------------------------------------------------------------------- */

int stdb_current_record_count_fc (
    const int *dbproc           /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_get_current_process_f ();

/* --------------------------------------------------------------------- */

int stdb_get_status_fc (
    const int *dbproc           /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_get_alternate_status_fc (
    const int *dbproc           /* i: index into context array  */
    );

/* --------------------------------------------------------------------- */

int stdb_set_alternate_status_fc (
    const int *dbproc,          /* i: index into context array   */
    const int *alternate_status /* i: alternate status to be set */
    );

/* --------------------------------------------------------------------- */

int stdb_is_null_f (
    const int  *dbproc,         /* i: index into context array   */
    void  *varaddr              /* i: bound variable             */
    );

/* --------------------------------------------------------------------- */

int stdb_in_transaction_fc (
    const int  *dbproc          /* i: index into context array   */
    ); 

#endif /* STDB_INTERF_INCLUDED */

/* NO CODE BEYOND THIS #ENDIF */

